stab.version<-function(){
cat("\n")
cat("------------------ stab for R v0.1.6 ------------------\n")
cat("\n developed by Hsin-ya Lee and Yung-jin Lee, 2007-2013.\n")
cat("\n This report was generated on",date(),"\n")
cat("\n\n")}